==> haskell-hi-file-parser-0.1.0.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hi-file-parser
version: 0.1.0.0
id: hi-file-parser-0.1.0.0-7EiC2CYYze5587j6sEZY6r
key: hi-file-parser-0.1.0.0-7EiC2CYYze5587j6sEZY6r
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Hussein Ait-Lahcen
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/stack/blob/master/subs/hi-file-parser/README.md>
category: Development
abi: 152553b96cbcd182ae511bcf7d0cdc8f
exposed: True
exposed-modules:
    HiFileParser
hidden-modules: Paths_hi_file_parser
import-dirs: /usr/lib/ghc-8.6.5/site-local/hi-file-parser-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hi-file-parser-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hi-file-parser-0.1.0.0
hs-libraries: HShi-file-parser-0.1.0.0-7EiC2CYYze5587j6sEZY6r
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    rio-0.1.11.0-8mwr5j0CL9r2TyMzDm1qRc
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock
haddock-html: /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hi-file-parser-0.1.0.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hi-file-parser
version: 0.1.0.0
id: hi-file-parser-0.1.0.0-FnqJjG4PWAk4JucgeTOVqu
key: hi-file-parser-0.1.0.0-FnqJjG4PWAk4JucgeTOVqu
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Hussein Ait-Lahcen
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/stack/blob/master/subs/hi-file-parser/README.md>
category: Development
abi: bc90744c2b054be7fc5a6a1b84b6874e
exposed: True
exposed-modules:
    HiFileParser
hidden-modules: Paths_hi_file_parser
import-dirs: /usr/lib/ghc-8.6.5/site-local/hi-file-parser-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hi-file-parser-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hi-file-parser-0.1.0.0
hs-libraries: HShi-file-parser-0.1.0.0-FnqJjG4PWAk4JucgeTOVqu
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    rio-0.1.12.0-GGGmuQzcJQDKkZbQi42S3E
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock
haddock-html: /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
